@@ -22,11 +22,6 @@ def _default_append_item(resources, key, value):
     elif isinstance(resources[key], list):
         resources[key] = resources[key] + value
 
-CPU_CAP = {
-    'savio': 20, 
-    'savio2': 24, 
-    'savio3': 32
-}
 
 class Slurm:
     def __init__(self, **args_dict):
@@ -50,25 +45,17 @@ class Slurm:
         _default_append_item(res, "module_list", ["gcc", "openmpi"])
         _default_item(res, "email", "jiahaoyao.math@gmail.com")
         _default_item(res, "conda_env", "qrl")
-
-        self.limit_cpu_cap(res)
         return res
 
-    def merge_config(self, res, res_):
+    def merge_config(slurm, res, res_):
         for key, value in res_.items():
             if key == "module_list":
                 _default_append_item(res, key, value)
             else:
                 _default_item(res, key, value)
 
-        self.limit_cpu_cap(res)
         return res
 
-    def limit_cpu_cap(self, res):
-        if res['partition'] in CPU_CAP: 
-            res['task_per_node'] = min(res['task_per_node'], CPU_CAP[res['partition']])
-        return res 
-
     def sub_script_head(self, res):
         ret = ""
         ret += "#!/bin/bash\n"
@@ -100,7 +87,7 @@ class Slurm:
         else:
             user_args_dict = load(user_config)
             self.merge_config(args_dict, user_args_dict)
-            dump(args_dict, user_config)
+            dump(user_args_dict, user_config)
 
         slurm_bash = self.sub_script_head(args_dict)
         dump(slurm_bash, "savio3.sh")
